"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApiGatewayComplianceChecker = void 0;
const aws_apigateway_1 = require("@aws-cdk/aws-apigateway");
const core_1 = require("@aws-cdk/core");
const compliance_checker_1 = require("./compliance-checker");
class ApiGatewayComplianceChecker extends compliance_checker_1.BaseComplianceChecker {
    constructor(config) {
        super({ apigateway: config });
    }
    checkCompliance(node) {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        if ((_b = (_a = this.config.apigateway) === null || _a === void 0 ? void 0 : _a.logging) !== null && _b !== void 0 ? _b : true) {
            this.checkAPILogging(node);
        }
        if ((_d = (_c = this.config.apigateway) === null || _c === void 0 ? void 0 : _c.ssl) !== null && _d !== void 0 ? _d : true) {
            this.checkSSL(node);
        }
        if ((_f = (_e = this.config.apigateway) === null || _e === void 0 ? void 0 : _e.xray) !== null && _f !== void 0 ? _f : true) {
            this.checkXRay(node);
        }
        if ((_h = (_g = this.config.apigateway) === null || _g === void 0 ? void 0 : _g.cacheDataEncrypted) !== null && _h !== void 0 ? _h : true) {
            this.checkCacheEncrypted(node);
        }
    }
    /**
     * [APIGateway.1] API Gateway REST and WebSocket API logging should be enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-apigateway-1
     */
    checkAPILogging(node) {
        if (!node.methodSettings) {
            // No explicit method settings defined, raise an error.
            core_1.Annotations.of(node).addError("[APIGateway.1] API Gateway REST and WebSocket API logging should be enabled");
        }
        else {
            if (!(0, core_1.isResolvableObject)(node.methodSettings) &&
                node.methodSettings.some((m) => !(0, core_1.isResolvableObject)(m) &&
                    (m.loggingLevel === undefined ||
                        m.loggingLevel === aws_apigateway_1.MethodLoggingLevel.OFF))) {
                // Explicit method settings defined, but not all of them have logging or logging is explicitly off.
                core_1.Annotations.of(node).addError("[APIGateway.1] API Gateway REST and WebSocket API logging should be enabled");
            }
        }
    }
    /**
     * [APIGateway.2] API Gateway REST API stages should be configured to use SSL certificates for backend authentication
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-apigateway-2
     */
    checkSSL(node) {
        if (!node.clientCertificateId) {
            core_1.Annotations.of(node).addError("[APIGateway.2] API Gateway REST API stages should be configured to use SSL certificates for backend authentication");
        }
    }
    /**
     * [APIGateway.3] API Gateway REST API stages should have AWS X-Ray tracing enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-apigateway-3
     */
    checkXRay(node) {
        if (!(0, core_1.isResolvableObject)(node.tracingEnabled) && !node.tracingEnabled) {
            core_1.Annotations.of(node).addError("[APIGateway.3] API Gateway REST API stages should have AWS X-Ray tracing enabled");
        }
    }
    /**
     * [APIGateway.5] API Gateway REST API cache data should be encrypted at rest
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-apigateway-5
     */
    checkCacheEncrypted(node) {
        if (!node.methodSettings) {
            core_1.Annotations.of(node).addError("[APIGateway.5] API Gateway REST API cache data should be encrypted at rest");
        }
        else {
            if (!(0, core_1.isResolvableObject)(node.methodSettings) &&
                node.methodSettings.some((m) => !(0, core_1.isResolvableObject)(m) && m.cachingEnabled && !m.cacheDataEncrypted)) {
                core_1.Annotations.of(node).addError("[APIGateway.5] API Gateway REST API cache data should be encrypted at rest");
            }
        }
    }
}
exports.ApiGatewayComplianceChecker = ApiGatewayComplianceChecker;
