"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DynamoDBComplianceChecker = exports.DynamoDBConfig = void 0;
const aws_dynamodb_1 = require("@aws-cdk/aws-dynamodb");
const core_1 = require("@aws-cdk/core");
const compliance_checker_1 = require("./compliance-checker");
class DynamoDBConfig {
}
exports.DynamoDBConfig = DynamoDBConfig;
class DynamoDBComplianceChecker extends compliance_checker_1.BaseComplianceChecker {
    constructor(config) {
        super({ dynamodb: config });
    }
    checkCompliance(node) {
        var _a, _b, _c, _d;
        if ((_b = (_a = this.config.dynamodb) === null || _a === void 0 ? void 0 : _a.autoScaling) !== null && _b !== void 0 ? _b : true) {
            this.checkAutoScaling(node);
        }
        if ((_d = (_c = this.config.dynamodb) === null || _c === void 0 ? void 0 : _c.pointInTimeRecovery) !== null && _d !== void 0 ? _d : true) {
            this.checkPointInTimeRecovery(node);
        }
    }
    /**
     * [DynamoDB.1] DynamoDB tables should automatically scale capacity with demand
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-dynamodb-1
     */
    checkAutoScaling(node) {
        // Look for ScalableTableAttribute or ScalableTarget
        if (node.node.scope instanceof aws_dynamodb_1.Table) {
            const table = node.node.scope;
            if (table.hasOwnProperty("tableScaling")) {
                const tableScaling = table["tableScaling"];
                if (!tableScaling.hasOwnProperty("scalableReadAttribute") ||
                    !tableScaling.hasOwnProperty("scalableWriteAttribute")) {
                    // If it's missing a scalable attribute, it's not a scalable table.
                    core_1.Annotations.of(node).addError("[DynamoDB.1] DynamoDB tables should automatically scale capacity with demand");
                }
            }
            else {
                // If it's missing tableScaling, it's not a scalable table.
                core_1.Annotations.of(node).addError("[DynamoDB.1] DynamoDB tables should automatically scale capacity with demand");
            }
        }
    }
    /**
     * [DynamoDB.2] DynamoDB tables should have point-in-time recovery enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-dynamodb-2
     */
    checkPointInTimeRecovery(node) {
        if (!node.pointInTimeRecoverySpecification) {
            // Nothing explicit about PITR being on or off, raise an error.
            core_1.Annotations.of(node).addError("[DynamoDB.2] DynamoDB tables should have point-in-time recovery enabled");
        }
        else {
            if (!(0, core_1.isResolvableObject)(node.pointInTimeRecoverySpecification) &&
                !node.pointInTimeRecoverySpecification.pointInTimeRecoveryEnabled) {
                // PITR is explicitly off, raise an error.
                core_1.Annotations.of(node).addError("[DynamoDB.2] DynamoDB tables should have point-in-time recovery enabled");
            }
        }
    }
}
exports.DynamoDBComplianceChecker = DynamoDBComplianceChecker;
