"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IAMPolicyComplianceChecker = void 0;
const aws_iam_1 = require("@aws-cdk/aws-iam");
const core_1 = require("@aws-cdk/core");
const compliance_checker_1 = require("./compliance-checker");
class IAMPolicyComplianceChecker extends compliance_checker_1.BaseComplianceChecker {
    constructor(config) {
        super({ iam: config });
    }
    checkCompliance(node) {
        var _a, _b, _c, _d;
        if ((_b = (_a = this.config.iam) === null || _a === void 0 ? void 0 : _a.fullAdmin) !== null && _b !== void 0 ? _b : true) {
            this.checkIAMPolicyFullAdmin(node);
        }
        if ((_d = (_c = this.config.iam) === null || _c === void 0 ? void 0 : _c.wildcardServiceActions) !== null && _d !== void 0 ? _d : true) {
            this.checkIAMPolicyServiceWildcards(node);
        }
    }
    /**
     * [IAM.1] IAM policies should not allow full "*" administrative privileges.
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-iam-1
     */
    checkIAMPolicyFullAdmin(node) {
        if (node.policyDocument.hasOwnProperty("statements")) {
            const statements = node.policyDocument.statements;
            if (statements.some((s) => s.effect === aws_iam_1.Effect.ALLOW &&
                s.action.some((a) => a === "*") &&
                s.resource.some((r) => r === "*"))) {
                core_1.Annotations.of(node).addError('[IAM.1] IAM policies should not allow full "*" administrative privileges.');
            }
        }
    }
    /**
     * [IAM.21] IAM customer managed policies that you create should not allow wildcard actions for services
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-iam-21
     */
    checkIAMPolicyServiceWildcards(node) {
        if (node.policyDocument.hasOwnProperty("statements")) {
            const statements = node.policyDocument.statements;
            if (statements.some((s) => s.effect === aws_iam_1.Effect.ALLOW &&
                s.action.some((a) => a.endsWith(":*")))) {
                core_1.Annotations.of(node).addError("[IAM.21] IAM customer managed policies that you create should not allow wildcard actions for services.");
            }
        }
    }
}
exports.IAMPolicyComplianceChecker = IAMPolicyComplianceChecker;
