import { CfnDBCluster, CfnDBInstance } from "@aws-cdk/aws-rds";
import { BaseComplianceChecker } from "./compliance-checker";
export interface RDSConfig {
    publicAccess?: boolean;
    storageEncrypted?: boolean;
    multiAz?: boolean;
    enhancedMonitoring?: boolean;
    deletionProtection?: boolean;
    logExports?: boolean;
    iamAuth?: boolean;
    autoMinorVersionUpgrades?: boolean;
    copyTagsToSnapshot?: boolean;
}
export declare class RDSComplianceChecker extends BaseComplianceChecker<CfnDBInstance | CfnDBCluster> {
    #private;
    constructor(config: RDSConfig);
    checkCompliance(node: CfnDBInstance | CfnDBCluster): void;
    /**
     * [RDS.2] RDS DB instances should prohibit public access, determined by the PubliclyAccessible configuration
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-2
     */
    private checkRDSPublicAccess;
    /**
     * [RDS.3] RDS DB instances should have encryption at rest enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-3
     */
    private checkRDSEncryption;
    /**
     * [RDS.5] RDS DB instances should be configured with multiple Availability Zones
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-5
     */
    private checkMultipleAZs;
    /**
     * [RDS.6] Enhanced monitoring should be configured for RDS DB instances and clusters
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-6
     */
    private checkEnhancedMonitoring;
    /**
     * [RDS.8] RDS DB instances should have deletion protection enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-8
     */
    private checkDeletionProtection;
    /**
     * [RDS.9] Database logging should be enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-9
     */
    private checkLogExports;
    /**
     * [RDS.10] IAM authentication should be configured for RDS instances & [RDS.12] IAM authentication should be configured for RDS clusters
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-10 & https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-12
     */
    private checkIAMAuthentication;
    /**
     * [RDS.13] RDS automatic minor version upgrades should be enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-13
     */
    private checkMinorVersionUpgrades;
    /**
     * [RDS.16] RDS DB clusters should be configured to copy tags to snapshots & [RDS.17] RDS DB instances should be configured to copy tags to snapshots
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-16 & https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-17
     */
    private checkCopyTagsToSnapshot;
}
